@@ -28,7 +28,13 @@ class LiteLLMConfig:
         "llama-3.1-70B-instruct",
         "llama-3.3-70b-versatile",
     ]
-    SUPPORTED_REASONING_MODELS = ["o1-mini", "o1", "r1", "gemini-2.0-flash-thinking"]
+    SUPPORTED_REASONING_MODELS = [
+        "o1-mini",
+        "o1",
+        "r1",
+        "o3-mini",
+        "gemini-2.0-flash-thinking",
+    ]
     SUPPORTED_EMBEDDING_MODELS = ["text-embedding-3-small", "text-embedding-3-large"]
 
     # Model mappings (optional)
@@ -39,7 +45,7 @@ class LiteLLMConfig:
         "llama-3.1-8B-instruct": "together_ai/meta-llama/Meta-Llama-3.1-8B-Instruct-Turbo",
         "llama-3.1-70B-instruct": "together_ai/meta-llama/Meta-Llama-3.1-70B-Instruct-Turbo",
         # gemini
-        "gemini-2.0-flash-thinking": "gemini-2.0-flash-thinking-exp",
+        "gemini-2.0-flash-thinking": "gemini-2.0-flash-thinking-exp-01-21",
         # groq
         "llama-3.3-70b-versatile": "groq/llama-3.3-70b-versatile",
     }
@@ -48,6 +54,7 @@ class LiteLLMConfig:
     REQUIRED_API_KEYS = {
         "o1-mini": "OPENAI_API_KEY",
         "o1": "OPENAI_API_KEY",
+        "o3-mini": "OPENAI_API_KEY",
         "gpt-4o": "OPENAI_API_KEY",
         "r1": "DEEPSEEK_API_KEY",
         "llama-3.1-8B-instruct": "TOGETHER_API_KEY",
